//
// demodialog.java
//
// Here's a simple demo applet that shows how to switch
// installed look-and-feel implementations while a
// Swing program is running.

import java.awt.*;
import java.awt.event.*;
import com.sun.java.swing.*;
import com.sun.java.swing.border.*;

public class demodialog extends JApplet
{
   private static String lfs[];
   private JButton btnYesNo, btnMessage, btnSelection;
   private MyCheckBoxListener clMyCheckBoxListener;
   private MyButtonListener clMyButtonListener;
   private JApplet This;
   private JLabel lbStatus;

   // recognize all available look and feels
   static 
   {
      // init lfs...
      lfs = new String[UIManager.getInstalledLookAndFeels().length];
      for (int i=0; i<UIManager.getInstalledLookAndFeels().length; i++)
         lfs[i] = UIManager.getInstalledLookAndFeels()[i].getClassName();
   }

   // the applet's init-method
   public void init()
   {
      // store own reference for internal classes
      This=this; 

      // create ui-element(s) and connect them to listener
      clMyButtonListener = new MyButtonListener();
      btnYesNo = new JButton("Yes/No-Dialog");
      btnYesNo.addActionListener(clMyButtonListener);
      btnMessage = new JButton("Message-Dialog");
      btnMessage.addActionListener(clMyButtonListener);
      btnSelection = new JButton("Selection-Dialog");
      btnSelection.addActionListener(clMyButtonListener);

      // create a panel for the radiobuttons
      clMyCheckBoxListener = new MyCheckBoxListener();
      JPanel pnCheckboxes = new JPanel();
      pnCheckboxes.setLayout( new BoxLayout(pnCheckboxes,BoxLayout.Y_AXIS) );
      pnCheckboxes.setBorder( new TitledBorder("Select look & feel") );

      // create radiobuttons, one for each available look and feel - connect each
      // to a buttongroup and to one and only listener class
      JRadioButton btnLook[] = new JRadioButton[lfs.length];
      ButtonGroup groupLook = new ButtonGroup();
      for (int i=0; i<lfs.length; i++)
      {
         btnLook[i]=new JRadioButton(lfs[i],(i==0)); // create new checkbox and select if 1st one
         groupLook.add(btnLook[i]);
         pnCheckboxes.add(btnLook[i]);
         btnLook[i].addActionListener(clMyCheckBoxListener);
      }

      // just a statusbar by using a simple label with a lowered border around it
      lbStatus=new JLabel();
      lbStatus.setBorder(new BevelBorder(BevelBorder.LOWERED));
      setStatus("Welcome... (C) 5/98 Dietrich Pfeifle, BROKAT Systeme Germany");

      // create a box for all the buttons
      Box clBox = new Box(BoxLayout.X_AXIS);
      clBox.add(btnYesNo);
      clBox.add(btnMessage);
      clBox.add(btnSelection);
         
      // add gui-items to contentpanel
      getContentPane().add(pnCheckboxes, BorderLayout.NORTH);
      getContentPane().add(clBox, BorderLayout.CENTER);
      getContentPane().add(lbStatus, BorderLayout.SOUTH);
   }

   // set the statustext
   public void setStatus( String strStatusText ) { lbStatus.setText("  "+strStatusText); }

   //
   // inner classes for eventhandling
   //

   private class MyButtonListener implements ActionListener
   {
      public void actionPerformed( ActionEvent eve )
      {
         setStatus("");
         if (eve.getSource()==btnYesNo)
         {
            //
            // Yes/No-Dialog
            //
            int res = JOptionPane.showConfirmDialog( This, "Do you know Maja ?", "Yes/No-Dialog", JOptionPane.YES_NO_OPTION );
            if (res==1)
               setStatus("She's my pretty baby");
         }
         else if (eve.getSource()==btnSelection)
         {
            //
            // Selection-Dialog
            //
            String s[] = { "Wine" , "Beer" };
            String res = (String) JOptionPane.showInputDialog( This, "What do you want to drink ?", "Select a drink", JOptionPane.PLAIN_MESSAGE, null, s, "Beer");
            if (res!=null)
               setStatus("Please wait for your "+res.toLowerCase());
            else
               setStatus("Aha, you want a softdrink...");
         }
         else if (eve.getSource()==btnMessage)
         {
            //
            // Message-Dialog
            //
            JOptionPane.showMessageDialog( This, "5/98 - Copyright by\nBrokat Systeme, Germany", "For your information", JOptionPane.INFORMATION_MESSAGE);
            setStatus("You read it.");
         }
      }
   }

   private class MyCheckBoxListener implements ActionListener
   {
      public void actionPerformed( ActionEvent eve )
      {
         try
         {
            // set look and feel to checkbox-label (equal to classname)
            UIManager.setLookAndFeel(eve.getActionCommand());
            // update complete gui-component tree (all components will set to new lf)
            SwingUtilities.updateComponentTreeUI(This);
            // following code forces vm to repaint all
            invalidate(); validate(); repaint();
            setStatus("look and feel set to '"+eve.getActionCommand()+"'");
         } catch (Exception e) {
            setStatus("Cannot set look and feel ! ("+e+")");
         }
      }
   }

}